Security Advisories (12)
CVE-2018-14041 (2018-07-13)

In Bootstrap before 4.1.2, XSS is possible in the data-target property of scrollspy.

CVE-2018-14042 (2018-07-13)

In Bootstrap before 4.1.2, XSS is possible in the data-container property of tooltip.

CVE-2020-11022 (2020-04-29)

In jQuery versions greater than or equal to 1.2 and before 3.5.0, passing HTML from untrusted sources - even after sanitizing it - to one of jQuery's DOM manipulation methods (i.e. .html(), .append(), and others) may execute untrusted code. This problem is patched in jQuery 3.5.0.

CVE-2020-11023 (2020-04-29)

In jQuery versions greater than or equal to 1.0.3 and before 3.5.0, passing HTML containing <option> elements from untrusted sources - even after sanitizing it - to one of jQuery's DOM manipulation methods (i.e. .html(), .append(), and others) may execute untrusted code. This problem is patched in jQuery 3.5.0.

CVE-2019-11358 (2019-04-20)

jQuery before 3.4.0, as used in Drupal, Backdrop CMS, and other products, mishandles jQuery.extend(true, {}, ...) because of Object.prototype pollution. If an unsanitized source object contained an enumerable __proto__ property, it could extend the native Object.prototype.

CVE-2015-9251 (2018-01-18)

jQuery before 3.0.0 is vulnerable to Cross-site Scripting (XSS) attacks when a cross-domain Ajax request is performed without the dataType option, causing text/javascript responses to be executed.

CVE-2011-4969 (2013-03-08)

Cross-site scripting (XSS) vulnerability in jQuery before 1.6.3, when using location.hash to select elements, allows remote attackers to inject arbitrary web script or HTML via a crafted tag.

CVE-2012-6708 (2018-01-18)

jQuery before 1.9.0 is vulnerable to Cross-site Scripting (XSS) attacks. The jQuery(strInput) function does not differentiate selectors from HTML in a reliable fashion. In vulnerable versions, jQuery determined whether the input was HTML by looking for the '<' character anywhere in the string, giving attackers more flexibility when attempting to construct a malicious payload. In fixed versions, jQuery only deems the input to be HTML if it explicitly starts with the '<' character, limiting exploitability only to attackers who can control the beginning of a string, which is far less common.

CVE-2020-7656 (2020-05-19)

jquery prior to 1.9.0 allows Cross-site Scripting attacks via the load method. The load method fails to recognize and remove "<script>" HTML tags that contain a whitespace character, i.e: "</script >", which results in the enclosed script logic to be executed.

CVE-2019-5428

Prototype Pollution is a vulnerability affecting JavaScript. Prototype Pollution refers to the ability to inject properties into existing JavaScript language construct prototypes, such as objects. JavaScript allows all Object attributes to be altered, including their magical attributes such as _proto_, constructor and prototype. An attacker manipulates these attributes to overwrite, or pollute, a JavaScript application object prototype of the base object by injecting other values. Properties on the Object.prototype are then inherited by all the JavaScript objects through the prototype chain. When that happens, this leads to either denial of service by triggering JavaScript exceptions, or it tampers with the application source code to force the code path that the attacker injects, thereby leading to remote code execution.

CVE-2014-6071 (2018-01-16)

jQuery 1.4.2 allows remote attackers to conduct cross-site scripting (XSS) attacks via vectors related to use of the text method inside after.

CVE-2018-14040 (2018-07-13)

Prototype Pollution is a vulnerability affecting JavaScript. Prototype Pollution refers to the ability to inject properties into existing JavaScript language construct prototypes, such as objects. JavaScript allows all Object attributes to be altered, including their magical attributes such as _proto_, constructor and prototype. An attacker manipulates these attributes to overwrite, or pollute, a JavaScript application object prototype of the base object by injecting other values. Properties on the Object.prototype are then inherited by all the JavaScript objects through the prototype chain. When that happens, this leads to either denial of service by triggering JavaScript exceptions, or it tampers with the application source code to force the code path that the attacker injects, thereby leading to remote code execution.

NAME

UR::Manual::Metadata - Overview of the metadata classes in UR

SYNOPSIS

use MyNamespace;
my $class_meta = MyNamespace::SomeClass->__meta__;
my @property_metas = $class_meta->direct_property_metas();
my @parent_class_metas = $class_meta->ancestry_class_metas();

my $table_obj = UR::DataSource::RDBMS::Table->get(
                table_name => $class_meta->table_name,
            );
my @column_objs = $table_obj->columns();

DESCRIPTION

The UR system creates and uses several classes and objects to represent information about the many classes and objects in the system - metadata. For example, for each class, there is an object, called a class metadata object, to represent it. Each property in a class has metadata. So does the relationship between parent and child classes and relationships involved in delegated properties. metadata about any database schemas your namespace knows about is also tracked and stored.

These classes define an API for introspection and reflection, a way for the system to change itself as it runs, and methods for tracking changes and applying those changes to files and databases.

APIs

The metadata API is divided into 5 primary parts:

Defining Classes

The mechanism for defining class structure, including their properties and relationships. It handles creating accessor/mutator methods for you. The syntax for defining classes is detailed in the UR::Object::Type::Initializer page.

Objects Representing Classes, Properties, Relationships, etc.

UR Classes aren't just conceptual entities like a package name, they have object instances to represent them. For every named class, you can get a UR::Object::Type instance with that class_name. Each property defined on that class has a UR::Object::Property with a matching class_name and property_name pair. Even those basic metadata classes have class, property and relationship metadata of their own.

Schema Objects

If you use the ur update classes command-line tool to manage the linkage between your database schema(s) and class structure (it's not necessary; you can also manage it by hand), then objects will also exist to represent the database entities. See also UR::DataSource::Meta

. tables UR::DataSource::RDBMS::Table
. columns UR::DataSource::RDBMS::TableColumn
. Foreign key constraints UR::DataSource::RDBMS::FkConstraint and UR::DataSource::RDBMS::FkConstraintColumn
. Primary key constraints UR::DataSource::RDBMS::PkConstraintColumn
. Unique constraints UR::DataSource::RDBMS::UniqueConstraintColumn
Namespaces, Contexts and Data Sources

Namespaces (UR::Namespace) collect and manage groups of related classes. Classes can be a member of one Namespace, and in practice will live in a subdirectory under the Namespace module's name.

Contexts (UR::Context) and Data Sources (UR::DataSource) provide a filtered view of the data that is reachable through the current Namespace.

Index, Change, Observer and other incidentals

And then there's everything else

UR::Object::Index objects are created by the system to handle get() requests for non-ID parameters.

UR::Change objects represent a change in the system during a software transaction, such as an object's property changind value or creating a new instance of something.

UR::Observer objects manage the change subscription system, where the application can be notified of changes through callbacks. See also "create_subscription" in UR::Object.